from setuptools import setup, find_packages

with open("README.md", "r") as f:
    page_description = f.read()



setup(
    name="super_colored_print",
    version="0.0.3",
    author="Victor Stein",
    author_email="victor.stein@outlook.com",
    description="Um pacote para facilitar a impressão de textos coloridos",
    long_description=page_description,
    long_description_content_type="text/markdown",
    url="https://github.com/vitorStein/super-print-package",
    packages=find_packages(),
    install_requires=[],
    python_requires='>=3.8',
)



class Colors:
    GREEN = '\033[92m' 
    YELLOW = '\033[93m'
    RED = '\033[91m'


def colored_print(text, color):

    if color == 'green':
        print(Colors.GREEN + text + Colors.GREEN)
    elif color == 'yellow':
        print(Colors.YELLOW + text + Colors.YELLOW)
    elif color == 'red':
        print(Colors.RED + text + Colors.RED)